@@ -1,7 +1,7 @@
 
-from pymonad.maybe import Maybe
 from typing import Generic, TypeVar
 from abc import ABC, abstractmethod
+from pymonad.maybe import Maybe
 
 T = TypeVar("T")
 
@@ -12,6 +12,8 @@ class BaseCache(ABC, Generic[T]):
 
     Base class for caches.
     """
+    def __init__(self):
+        self._name = "" 
 
     @abstractmethod
     def get(self, key: int) -> Maybe[T]:
@@ -20,3 +22,9 @@ class BaseCache(ABC, Generic[T]):
     @abstractmethod
     def set(self, key: int, val: T) -> None:
         pass
+
+    def _key(self, key:int):
+        return self._name + "/" + str(key) if self._name else str(key)
+
+    def set_name(self, name: str):
+        self._name = name
